@@ -73,7 +73,7 @@ setAs("data.frame", "transactions", function(from) {
 
 
 ###*****************************************************
-### subset
+### subset + combine
 
 setMethod("[", signature(x = "transactions"),
     function(x, i, j, ..., drop = FALSE) {
@@ -87,6 +87,17 @@ setMethod("[", signature(x = "transactions"),
     }
     })
 
+setMethod("combine", signature(first = "transactions"),
+    function(first, ...){
+    
+    ti <- first@transactionInfo
+    lapply(list(...), FUN = function(x)
+      ti <<- rbind(ti, x@transactionInfo))
+    
+    new("transactions", combine(first = as(first, "itemMatrix"), ...), 
+      transactionInfo = ti)
+    })
+
 
 ###*****************************************************
 ### show / summary
